@@ -8,6 +8,7 @@ from typing import Iterable
 
 import torch
 from accelerate import Accelerator, DistributedType
+from accelerate.utils import set_seed
 from torch.utils.data import DataLoader
 
 from pytorch_accelerated.callbacks import (
@@ -173,6 +174,7 @@ class Trainer:
         Create an instance of :class:`accelerate.Accelerator` which will be used to manage training.
         :return:
         """
+
         return Accelerator()
 
     def create_train_dataloader(
@@ -536,6 +538,8 @@ class Trainer:
         """
         self._accelerator.free_memory()
         self._accelerator = self._create_accelerator()
+        # set different seed on each device to ensure any augmentations are different across processes
+        set_seed(42, device_specific=True)
 
         components = [self.model, self.optimizer]
 
@@ -701,25 +705,22 @@ class Trainer:
                 "on_train_step_start",
                 self,
             )
-            batch_output = self.calculate_train_batch_loss(batch)
-            self._loss_tracker.update(
-                self.gather(batch_output["loss"]).detach().mean().item(),
-                batch_output["batch_size"],
-            )
-            if self.run_config.gradient_accumulation_steps > 1:
-                batch_output["loss"] /= self.run_config.gradient_accumulation_steps
 
-            self.callback_handler.call_event(
-                "on_train_step_end", self, batch_output=batch_output, batch=batch
-            )
-            self.backward_step(batch_output["loss"])
+            perform_gradient_update = (
+                (step + 1) % self.run_config.gradient_accumulation_steps == 0
+            ) or (step + 1 == len(train_dl))
+
+            if not perform_gradient_update:
+                # accumulate gradients locally
+                with self._accelerator.no_sync(self.model):
+                    self._perform_forward_and_backward_passes(batch)
+            else:
+                self._perform_forward_and_backward_passes(batch)
 
             if self.run_config.gradient_clip_value is not None:
                 self._clip_gradients()
 
-            if (step + 1) % self.run_config.gradient_accumulation_steps == 0 or (
-                step + 1 == len(train_dl)
-            ):
+            if perform_gradient_update:
                 self.optimizer_step()
                 if (
                     self.scheduler is not None
@@ -735,6 +736,26 @@ class Trainer:
             self,
         )
 
+    def _perform_forward_and_backward_passes(self, batch):
+        """
+        Perform the forward and backward passes of the training loop
+
+        :param batch: the current batch of data
+        """
+        batch_output = self.calculate_train_batch_loss(batch)
+        if self.run_config.gradient_accumulation_steps > 1:
+            batch_output["loss"] /= self.run_config.gradient_accumulation_steps
+
+        self._loss_tracker.update(
+            self.gather(batch_output["loss"]).detach().mean().item(),
+            batch_output["batch_size"],
+        )
+
+        self.callback_handler.call_event(
+            "on_train_step_end", self, batch_output=batch_output, batch=batch
+        )
+        self.backward_step(batch_output["loss"])
+
     def _clip_gradients(self):
         """
         Clip the gradients of the model's parameters that fall outside of the threshold specified in :meth:`~Trainer.train`.
